# psychopy-labjack
Extension package for adding support for [LabJack](https://labjack.com/) devices to PsychoPy.
    
## Installing

Install this package with the following shell command:: 

    pip install psychopy-labjack

You may also use PsychoPy's builtin package manager to install this package.

## Usage

Once the package is installed, PsychoPy will automatically load it when started and make objects available within the
`psychopy.hardware.labjacks` namespace.

